@@ -63,7 +63,7 @@ def get_ptype(archive_type, proxy_type):
 
 class ProxyRecord:
     def __init__(self, pid=None, time=None, value=None, lat=None, lon=None, ptype=None,
-        value_name=None, value_unit=None, time_name=None, time_unit=None):
+        value_name=None, value_unit=None, time_name=None, time_unit=None, seasonality=None):
         '''
         Parameters
         ----------
@@ -103,6 +103,7 @@ class ProxyRecord:
         self.value_unit = value_unit
         self.time_name = 'Time' if time_name is None else time_name
         self.time_unit = 'yr' if time_unit is None else time_unit
+        self.seasonality = seasonality
 
     def copy(self):
         return copy.deepcopy(self)
@@ -221,11 +222,8 @@ class ProxyRecord:
 
         Parameters
         ----------
-        field : p2k.climate.ClimateField or p2k.climate.ClimateDataset
+        fields : p2k.climate.ClimateField or p2k.climate.ClimateDataset
             the climate field
-
-        field_name : str
-            the string name for the field
         '''
         if isinstance(fields, ClimateDataset):
             fields = list(fields.fields.values())
@@ -238,7 +236,7 @@ class ProxyRecord:
         for field in fields:
             name = field.da.name
             if tag is not None:
-                name = f'{tag}-{name}'
+                name = f'{tag}_{name}'
 
             nda = field.da.sel(lat=self.lat, lon=self.lon, **_kwargs)
             if not hasattr(self, 'clim'):
@@ -289,7 +287,12 @@ class ProxyRecord:
         value_lb = visual.make_lb(self.value_name, self.value_unit)
         ax['ts'].set_xlabel(time_lb)
         ax['ts'].set_ylabel(value_lb)
-        ax['ts'].set_title(f'{self.pid} @ (lat:{self.lat}, lon:{self.lon}) | Type: {self.ptype}')
+
+        title = f'{self.pid} @ (lat:{self.lat}, lon:{self.lon}) | Type: {self.ptype}'
+        if self.seasonality is not None:
+            title += f'\nSeasonality: {self.seasonality}'
+        ax['ts'].set_title(title)
+
         if legend:
             ax['ts'].legend()
 
